@@ -98,7 +98,7 @@ def AGW_Account(key):
 
 def AGW_DomainName(key):
     for n, v in getattr(cfg, key).items():
-        if not v['IBOXENABLED']:
+        if not v['IBOX_ENABLED']:
             continue
 
         resname = f'{key}{n}'
@@ -166,7 +166,8 @@ def AGW_ApiKeys(key):
         # parameters
         p_Enabled = Parameter(f'{resname}Enabled')
         p_Enabled.Description = (
-            f'{resname}Enabled - empty for default based on env/role')
+            f'{resname}Enabled - empty for mapped value')
+        p_Enabled.AllowedValues = ['', 'yes', 'no']
 
         p_UsagePlan = Parameter(f'{resname}UsagePlan')
         p_UsagePlan.Description = (
