@@ -9,7 +9,6 @@ from .shared import (Parameter, get_endvalue, get_expvalue, get_subvalue,
                      auto_get_props, get_condition, add_obj)
 from .cfn import *
 from .codedeploy import CD_DeploymentGroup
-from .securitygroup import SG_SecurityGroupsEC2
 from .iam import IAMInstanceProfile
 
 try:
@@ -484,18 +483,8 @@ def AS_ScheduledActionsEC2(key):
     for n, v in getattr(cfg, key).items():
         resname = f'{key}{n}'
 
-        # trick - obj mapped props have same name/key of the one used for
-        # code, so i create a subpro named IBOXCODE and used that as
-        # rootdict
-        try:
-            rootdict = cfg.ScheduledAction[n]['IBOXCODE']
-        except Exception:
-            kwargs = {}
-        else:
-            kwargs = {'rootdict': rootdict}
-
         r_ScheduledActions = asg.ScheduledAction(resname)
-        auto_get_props(r_ScheduledActions, **kwargs)
+        auto_get_props(r_ScheduledActions)
         add_obj(r_ScheduledActions)
 
 
@@ -503,7 +492,7 @@ def AS_ScalingPolicies(key):
     Out_String = []
     Out_Map = {}
     for n, v in getattr(cfg, key).items():
-        if not v['IBOXENABLED']:
+        if not v['IBOX_ENABLED']:
             continue
 
         resname = f'{key}{n}'
@@ -669,7 +658,7 @@ def AS_LaunchTemplate():
         InitConfigELBInternal = ASInitConfigELBApplicationInternal()
         CfmInitArgs['ELBWAITER'] = InitConfigELBInternal
 
-    SecurityGroups = SG_SecurityGroupsEC2()
+    SecurityGroups = cfg.SecurityGroupsImport
 
     # Resources
     R_LaunchTemplate = ec2.LaunchTemplate(
@@ -735,8 +724,8 @@ def AS_Autoscaling(key):
 
     LaunchTemplateTags = AS_LaunchTemplate()
 
-    R_ASG = asg.AutoScalingGroup('AutoScalingGroup')
-    auto_get_props(R_ASG, f'{key}Base')
+    R_ASG = asg.AutoScalingGroup('AutoScalingGroupBase')
+    auto_get_props(R_ASG)
 
     R_ASG.LoadBalancerNames = LoadBalancers
     R_ASG.TargetGroupARNs = TargetGroups
