@@ -79,6 +79,11 @@ def cfn_ecs_cluster():
                 '/etc/ecs/ecs.config': {
                     'content': Join('\n', [
                         Sub('ECS_CLUSTER=${Cluster}'),
+                        'ECS_ENABLE_SPOT_INSTANCE_DRAINING=true',
+                        get_subvalue(
+                            'ECS_IMAGE_PULL_BEHAVIOR=${1M}',
+                            'ECSClusterBaseAgentCfgImagePullBehavior'
+                        ),
                         If(
                             'GPUInstance',
                             'ECS_DISABLE_PRIVILEGED=false',
