@@ -203,7 +203,7 @@ def R53_HostedZones(key):
 
             # conditions
             c_Enabled = get_condition(
-                resname, 'not_equals', 'None', f'{mapname}Enabled')
+                resname, 'equals', 'yes', f'{mapname}Enabled')
 
             add_obj(c_Enabled)
 
@@ -235,7 +235,7 @@ def R53_HostedZones(key):
 
 def R53_RecordSets(key):
     for n, v in getattr(cfg, key).items():
-        if not v['IBOXENABLED']:
+        if not v['IBOX_ENABLED']:
             continue
         resname = f'RecordSet{n}'
 
