@@ -23,7 +23,7 @@ def stack_add_res():
         # Automatically create override conditions for parameters
         if not n.startswith(PARAMETERS_SKIP_OVERRIDE_CONDITION):
 
-            if n == 'LaunchTemplateDataInstanceType':
+            if n.endswith('InstanceType'):
                 default = 'default'
             elif n == 'SecurityGroups':
                 default = cfg.SECURITY_GROUPS_DEFAULT
@@ -76,20 +76,25 @@ def add_obj(obj):
 
 def add_objoutput(res):
     try:
-        iboxprops = res.IBOX
+        iboxprops = res.IBOX_PROPS
     except Exception:
         pass
     else:
-        join_list = []
-        for n in res.Value.split():
-            n = n.strip()
-            if n.startswith('${'):
-                n = n.strip('${}')
-                n = eval(f'iboxprops.{n}')
-            join_list.append(n)
+        if isinstance(res.Value, str):
+            mapname = iboxprops['MAP'][res.title]
+            join_list = []
+            for n in res.Value.split():
+                n = n.strip()
+                if n.startswith('${'):
+                    n = n.strip('${}')
+                    obj = iboxprops[f'{mapname}{n}'][0]
+                    propname = iboxprops[f'{mapname}{n}'][1]
+                    n = getattr(obj, propname)
+                join_list.append(n)
 
-        res.Value = Join('', join_list)
-        del res.properties['IBOX']
+            res.Value = Join('', join_list)
+
+        del res.properties['IBOX_PROPS']
 
 
 def do_no_override(action):
@@ -119,11 +124,8 @@ def get_endvalue(param, ssm=False, condition=False, nocondition=False,
         return override_value
 
     def _get_value():
-        # Its not pythonic, but it's only way to avoid circular import problems
-        from .securitygroup import (SG_SecurityGroupsTSK, SG_SecurityGroupsECS)
-
         if resname:
-            IBOXRESNAME = resname
+            IBOX_RESNAME = resname
         # if param in fixedvalues means its value do not changes
         # based on Env/Region so hardcode the value in json, ...
         if param in fixedvalues:
@@ -133,7 +135,7 @@ def get_endvalue(param, ssm=False, condition=False, nocondition=False,
                 scope_g = globals()
                 scope_l = locals()
                 value = [
-                    eval(r, scope_g, scope_l) if r.startswith(
+                    eval(r, scope_g, scope_l) if str(r).startswith(
                         cfg.EVAL_FUNCTIONS_IN_CFG) else r for r in value
                 ]
             if isinstance(value, str):
@@ -390,14 +392,19 @@ def import_lambda(name):
 
 
 def auto_get_props(obj, mapname=None, key=None, rootdict=None):
-    # IBOXRESNAME can be used in yaml
-    IBOXOBJ = obj
-    IBOXRESNAME = obj.title
-    IBOXMAPNAME = mapname
+    # IBOX_RESNAME can be used in yaml
+    IBOX_RESNAME = obj.title
+    IBOX_MAPNAME = mapname
+
+    # create a dict where i will put all property with a flat hierarchy
+    # with the name equals to the mapname and the relative value.
+    # Later i will assign this dict to the relative output object using
+    # IBOX_OUTPUT
+    IBOX_PROPS = {'MAP': {}}
 
     def _iboxif(if_wrapper, mapname, value):
-        condname = if_wrapper[0].replace('IBOXMAPNAME_', mapname)
-        condname = condname.replace('IBOXRESNAME', IBOXRESNAME)
+        condname = if_wrapper[0].replace('IBOX_MAPNAME_', mapname)
+        condname = condname.replace('_', IBOX_RESNAME)
         condvalues = []
         for i in if_wrapper[1:3]:
             if isinstance(i, str) and i.startswith(cfg.EVAL_FUNCTIONS_IN_CFG):
@@ -406,7 +413,7 @@ def auto_get_props(obj, mapname=None, key=None, rootdict=None):
                 v = i
             condvalues.append(v)
 
-        if condvalues[0] == 'IBOXIFVALUE':
+        if condvalues[0] == 'IBOX_IFVALUE':
             value = If(condname, value, condvalues[1])
         else:
             value = If(condname, condvalues[0], value)
@@ -428,11 +435,11 @@ def auto_get_props(obj, mapname=None, key=None, rootdict=None):
                     v['Value'] = get_endvalue(f'{mapname_obj}{k}Value')
 
                 try:
-                    if_wrapper = v['IBOXIF']
+                    if_wrapper = v['IBOX_IF']
                 except Exception:
                     pass
                 else:
-                    del v['IBOXIF']
+                    del v['IBOX_IF']
                     v = _iboxif(if_wrapper, mapname, v)
 
                 prop_list.append(v)
@@ -479,8 +486,8 @@ def auto_get_props(obj, mapname=None, key=None, rootdict=None):
             prop_list = []
             prop_class = props[obj_propname][0][0]
             for o, v in key[obj_propname].items():
-                if o == 'IBOXIF':
-                    # element named IBOXIF must no be parsed
+                if o == 'IBOX_IF':
+                    # element named IBOX_IF must no be parsed
                     # is needed for wrapping whole returned obj in _populate
                     continue
                 name_o = str(o)
@@ -491,7 +498,7 @@ def auto_get_props(obj, mapname=None, key=None, rootdict=None):
 
                 # trick to wrapper single obj in If Condition
                 try:
-                    if_wrapper = v['IBOXIF']
+                    if_wrapper = v['IBOX_IF']
                 except Exception:
                     prop_list.append(prop_obj)
                 else:
@@ -511,46 +518,46 @@ def auto_get_props(obj, mapname=None, key=None, rootdict=None):
         def _try_PCO_in_obj(key):
             def _parameter(k):
                 for n, v in k.items():
-                    n = n.replace('IBOXRESNAME', IBOXRESNAME)
+                    n = n.replace('_', IBOX_RESNAME)
                     parameter = Parameter(n)
                     _populate(parameter, rootdict=v)
                     add_obj(parameter)
 
             def _condition(k):
-                # this is needed or eval do not find IBOXRESNAME??
-                IBOXRESNAME
-                IBOXMAPNAME
+                # this is needed or eval do not find IBOX_RESNAME??
+                IBOX_RESNAME
+                IBOX_MAPNAME
                 for n, v in k.items():
-                    n = n.replace('IBOXRESNAME', IBOXRESNAME)
-                    if IBOXMAPNAME:
-                        n = n.replace('IBOXMAPNAME', IBOXMAPNAME)
+                    if IBOX_MAPNAME:
+                        n = n.replace('IBOX_MAPNAME', IBOX_MAPNAME)
+                    n = n.replace('_', IBOX_RESNAME)
                     condition = {n: eval(v)}
                     add_obj(condition)
 
-            def _output(k):
+            def _output_no_more_used(k):
                 for n, v in k.items():
-                    n = n.replace('IBOXRESNAME', IBOXRESNAME)
+                    n = n.replace('_', IBOX_RESNAME)
                     output = Output(n)
                     _populate(output, rootdict=v)
                     add_obj(output)
 
-            def _objoutput(k):
+            def _output(k):
                 for n, v in k.items():
-                    n = n.replace('IBOXRESNAME', IBOXRESNAME)
+                    n = n.replace('_', IBOX_RESNAME)
                     output = Output(n)
                     _populate(output, rootdict=v)
                     # alter troposphere obj and add IBOX property
-                    output.props['IBOX'] = (object, False)
-                    output.propnames.append('IBOX')
+                    output.props['IBOX_PROPS'] = (dict, False)
+                    output.propnames.append('IBOX_PROPS')
                     # assign auto_get_props populated obj to IBOX property
-                    output.IBOX = IBOXOBJ
+                    output.IBOX_PROPS = IBOX_PROPS
+                    output.IBOX_PROPS['MAP'][n] = mapname
                     add_obj(output)
 
             func_map = {
-                'IBOXPARAMETER': _parameter,
-                'IBOXCONDITION': _condition,
-                'IBOXOUTPUT': _output,
-                'IBOXOBJOUTPUT': _objoutput,
+                'IBOX_PARAMETER': _parameter,
+                'IBOX_CONDITION': _condition,
+                'IBOX_OUTPUT': _output,
             }
             for pco in list(func_map.keys()):
                 try:
@@ -560,6 +567,20 @@ def auto_get_props(obj, mapname=None, key=None, rootdict=None):
                 else:
                     func_map[pco](k)
 
+        def _auto_PO(name, conf, mode, value=''):
+            if mode == 'p':
+                parameter_base = {'Description': 'Empty for mapped value'}
+                parameter_base.update(conf)
+                parameter = {'IBOX_PARAMETER': {
+                    f'{mapname}{name}': parameter_base}}
+                _try_PCO_in_obj(parameter)
+            if mode == 'o':
+                output_base = {'Value': value}
+                output_base.update(conf)
+                output = {'IBOX_OUTPUT': {
+                    f'{mapname}{name}': output_base}}
+                _try_PCO_in_obj(output)
+
         # Allowed object properties
         props = vars(obj)['propnames']
         props.extend(vars(obj)['attributes'])
@@ -568,58 +589,80 @@ def auto_get_props(obj, mapname=None, key=None, rootdict=None):
         _try_PCO_in_obj(key)
 
         for propname in key:
-            if propname not in props:
-                # NO match between propname and one of obj props
-                continue
             key_value = key[propname]
 
-            # set value
-            if isinstance(key_value, dict):
-                # key value is a dict, get populated object
-                value = _get_obj(obj, key, propname, mapname)
-            elif (isinstance(key_value, str)
-                    and key_value.startswith('IBOXRESNAME')):
-                # replace IBOXRESNAME string with IBOXRESNAME value
-                value = key_value.replace('IBOXRESNAME', IBOXRESNAME)
-            elif rootdict:
-                # rootdict is needed for lib/efs.py EFS_FileStorage SGIExtra,
-                # is passed as a dictionary to parse for parameters
-                value = get_endvalue(
-                    f'{mapname}{propname}', fixedvalues=rootdict,
-                    resname=IBOXRESNAME)
-            elif (isinstance(key_value, str)
-                    and key_value.startswith('get_endvalue(')):
-                # Usefull to migrate code in yaml using auto_get_props
-                # get_endvalue is used only when migrating code
+            if propname.endswith(
+                    ('.IBOX_PCO', '.IBOX_AUTO_PO', '.IBOX_AUTO_P')):
+                if propname.endswith('.IBOX_PCO'):
+                    # If there is a key ending with {prop}.IBOX_PCO process it
+                    _try_PCO_in_obj(key_value)
+                if propname.endswith(('.IBOX_AUTO_PO', '.IBOX_AUTO_P')):
+                    # Automatically create parameter
+                    _auto_PO(propname.split('.')[0], key_value, 'p')
+                continue
+
+            if propname in props and f'{propname}.IBOX_CODE' not in key:
+                # propname is an obj props and there is no propname key
+                # defining code (look down for processing IBOX_CODE propname).
+
+                # set value
+                if isinstance(key_value, dict):
+                    # key value is a dict, get populated object
+                    value = _get_obj(obj, key, propname, mapname)
+                elif (isinstance(key_value, str)
+                        and key_value.startswith('IBOX_RESNAME')):
+                    # replace IBOX_RESNAME string with IBOX_RESNAME value
+                    value = key_value.replace('IBOX_RESNAME', IBOX_RESNAME)
+                elif rootdict:
+                    # rootdict is needed by lib/efs.py EFS_FileStorage SGIExtra
+                    # where is passed as a dictionary to parse for parameters
+                    value = get_endvalue(
+                        f'{mapname}{propname}', fixedvalues=rootdict,
+                        resname=IBOX_RESNAME)
+                elif (isinstance(key_value, str)
+                        and key_value.startswith('get_endvalue(')):
+                    # Usefull to migrate code in yaml using auto_get_props
+                    # get_endvalue is used only when migrating code
+                    value = eval(key_value)
+                else:
+                    value = get_endvalue(
+                        f'{mapname}{propname}', resname=IBOX_RESNAME)
+
+                if key_value == 'IBOX_IFCONDVALUE':
+                    # auto add condition and wrap value in AWS If Condition
+                    add_obj(get_condition(f'{mapname}{propname}',
+                                          'not_equals', 'IBOX_IFCONDVALUE'))
+                    value = If(
+                        f'{mapname}{propname}',
+                        value,
+                        Ref('AWS::NoValue'))
+                elif (isinstance(key_value, str)
+                        and key_value.startswith('IBOX_IF')):
+                    # trick to wrapper value in If Condition
+                    if_list = key_value.split()[1:4]
+                    value = _iboxif(if_list, mapname, value)
+
+                # trick to wrapper recursed returned value in If Condition
+                try:
+                    if_wrapper = key_value['IBOX_IF']
+                except Exception:
+                    pass
+                else:
+                    value = _iboxif(if_wrapper, mapname, value)
+
+                if propname == 'Condition' and not isinstance(value, str):
+                    # Avoid intercepting a Template Condition
+                    # as a Resource Condition
+                    continue
+            elif propname.endswith('.IBOX_CODE'):
+                # If there is a key ending with {prop}.IBOX_CODE
+                # eval it and use it as prop value.
+                # Usefull if a str value need to be processed by a code.
+                # (like in autoscaling-scheduledactions.yml)
                 value = eval(key_value)
+                propname = propname.replace('.IBOX_CODE', '')
             else:
-                value = get_endvalue(
-                    f'{mapname}{propname}', resname=IBOXRESNAME)
-
-            if key_value == 'IBOXIFCONDVALUE':
-                # auto add condition and wrap value in AWS If Condition
-                add_obj(get_condition(f'{mapname}{propname}',
-                                      'not_equals', 'IBOXIFCONDVALUE'))
-                value = If(
-                    f'{mapname}{propname}',
-                    value,
-                    Ref('AWS::NoValue'))
-            elif (isinstance(key_value, str)
-                    and key_value.startswith('IBOXIF')):
-                # trick to wrapper value in If Condition
-                if_list = key_value.split()[1:4]
-                value = _iboxif(if_list, mapname, value)
-
-            # trick to wrapper recursed returned value in If Condition
-            try:
-                if_wrapper = key_value['IBOXIF']
-            except Exception:
-                pass
-            else:
-                value = _iboxif(if_wrapper, mapname, value)
-
-            if propname == 'Condition' and not isinstance(value, str):
-                # Avoid intercepting Template Condition as Resource Condition
+                # NO match between propname and one of obj props
                 continue
 
             # Finally set obj property
@@ -627,10 +670,19 @@ def auto_get_props(obj, mapname=None, key=None, rootdict=None):
                 setattr(obj, propname, value)
             except TypeError:
                 pass
+            else:
+                # populate IBOX_PROPS dict
+                IBOX_PROPS[f'{mapname}{propname}'] = (obj, propname)
+
+                # Automatically create output
+                for n in [f'{propname}.IBOX_AUTO_PO',
+                          f'{propname}.IBOX_AUTO_O']:
+                    if n in key:
+                        _auto_PO(propname, key[n], 'o', value)
 
         # title override
         try:
-            obj.title = key['IBOXTITLE']
+            obj.title = key['IBOX_TITLE']
         except Exception:
             pass
 
